@@ -22,6 +22,10 @@ import operator
 import prettytable
 import requests
 
+from openstack_governance import governance
+from openstack_governance import members
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -177,7 +181,7 @@ def all_changes():
             break
 
 
-def get_one_status(change, delegates):
+def get_one_status(change, delegates, tc_members):
     topic = change.get('topic', 'unknown topic')
     subject = change.get('subject')
     owner = change.get('owner', {}).get('name')
@@ -215,10 +219,17 @@ def get_one_status(change, delegates):
         # At least 5 positive votes and more positive than negative
         # votes.
         votes_to_approve = (votes[1] >= 5 and votes[1] > votes[-1])
-
-        # Wait at least 3 days after reaching majority.
         reached_majority = when_majority(change, 5)
-        if reached_majority:
+
+        parts.append('last change on {}'.format(latest_created.date()))
+
+        # At least 7 days old.
+        if age < datetime.timedelta(8):
+            time_to_approve = False
+            parts.append('has not been open 7 days')
+            earliest = str(latest_created.date() + datetime.timedelta(8))
+        elif reached_majority:
+            # Wait at least 3 days after reaching majority.
             earliest = str(reached_majority.date() + datetime.timedelta(4))
             since_majority = now.date() - reached_majority.date()
             time_to_approve = since_majority > datetime.timedelta(3)
@@ -362,10 +373,30 @@ def get_one_status(change, delegates):
         ' V:' + format_votes(votes),
     ])
 
+    tc_member_votes = {}
+    for name in tc_members:
+        if has_approved(name, change):
+            tc_member_votes[name] = '+'
+        elif has_rejected(name, change):
+            tc_member_votes[name] = '-'
+        elif has_commented(name, change):
+            tc_member_votes[name] = 'C'
+        else:
+            tc_member_votes[name] = ' '
+    member_votes = '\n'.join(
+        '{} : {}'.format(value, name)
+        for name, value in sorted(tc_member_votes.items())
+    )
+
     return {
         'Topic': topic,
         'Subject': subject,
-        'Summary': '\n'.join([subject.strip(), '', url]),
+        'Summary': '\n'.join([
+            subject.strip(),
+            '',
+            url,
+            'Submitted by: {}'.format(owner.strip())
+        ]),
         'Owner': owner,
         'URL': url,
         'Age': age.days,
@@ -376,6 +407,7 @@ def get_one_status(change, delegates):
                              earliest]),
         'Earliest': earliest,
         'Votes': votes,
+        'Members': member_votes,
     }
 
 
@@ -394,14 +426,24 @@ def main():
         level=args.log_level,
     )
 
+    tc_members = [
+        m.get('name')
+        for m in members.parse_members_file('./reference/members.yaml')
+    ]
+
+    gov = governance.Governance.from_local_repo()
+    release_team = gov.get_team('Release Management')
+
     delegates = {
         'stable:follows-policy': 'Tony Breeds',
         'vulnerability:managed': 'VMT',
-        'release-management': 'Sean McGinnis',
+        'release-management': release_team.ptl['name'],
     }
+    for tag, name in sorted(delegates.items()):
+        print('Delegating {} tags to {}'.format(tag, name))
 
     status = sorted(
-        (get_one_status(change, delegates)
+        (get_one_status(change, delegates, tc_members)
          for change in all_changes()),
         key=operator.itemgetter('URL'),
     )
@@ -410,6 +452,7 @@ def main():
         'Summary',
         'Status',
         'Votes',
+        'Members',
     )
 
     x = prettytable.PrettyTable(
@@ -419,6 +462,7 @@ def main():
     x.align['Summary'] = 'l'
     x.align['Status'] = 'l'
     x.align['Votes'] = 'l'
+    x.align['Members'] = 'l'
     for row in status:
         x.add_row([row[c] for c in columns])
     print(x.get_string())
